.. _citation:

Citation
=================

WRF-Python has a Digital Object Identifier (DOI), which is a persistent 
identifier for web-based resources. The wrf-python DOI, when used in URL form, 
https://doi.org/10.5065/D6W094P1, provides a persistent link to the wrf-python 
Github page. The benefit of DOIs is that they are widely accepted by academic 
publishers as citable locators for scholarly objects.

If you author a paper that involves data analysis with wrf-python, or 
visualizations created with wrf-python, we would like to ask you to please 
cite wrf-python. This helps us better understand the impact of the software on 
the scientific community, which in turns helps us maintain support for the 
effort.

You can cite wrf-python using the following citation:

.. code-block:: none

   Ladwig, W. (2017). wrf-python (Version x.x.x) [Software]. Boulder, Colorado: UCAR/NCAR. https://doi.org/10.5065/D6W094P1 
    
.. note:: 

   The version number x.x.x should be set to the version of wrf-python that you are using.